@@ -272,7 +272,11 @@ class Sofa():
 
     def info(self, info):
         """
-        Print information about a SOFA object
+        Print information about the convention of a SOFA object.
+
+        Prints the variable type (attribute, double, string), shape, flags
+        (mandatory, read only) and comment (if any) for each or selected
+        entries.
 
         Parameters
         ----------
@@ -359,6 +363,76 @@ class Sofa():
 
         print(info_str)
 
+    def inspect(self, file=None):
+        """
+        Get information about data inside a SOFA object.
+
+        Prints the values of all attributes and variables with six or less
+        entries and the shapes and type of all numeric and string variables.
+        When printing the values of arrays, single dimensions are discarded for
+        easy of display, i.e., an array of shape (1, 3, 2) will be displayed as
+        an array of shape (3, 2).
+
+        Parameters
+        ----------
+        file : str
+            Full path of a file under which the information is to be stored in
+            plain text. The default ``None`` does only print the information.
+        """
+
+        # update the private attribute `_convention` to make sure the required
+        # meta data is in place
+        self.verify(version="match")
+
+        # list of all attributes
+        keys = [k for k in self.__dict__.keys() if not k.startswith("_")]
+
+        # start printing the information
+        info_str = (
+            f"{self.GLOBAL_SOFAConventions} "
+            F"{self.GLOBAL_SOFAConventionsVersion} "
+            f"(SOFA version {self.GLOBAL_Version})\n")
+        info_str += "-" * len(info_str) + "\n"
+
+        for key in keys:
+
+            info_str += key + " : "
+            value = getattr(self, key)
+
+            # information for attributes and scalars
+            if self._convention[key]["type"] == "attribute" or value.size == 1:
+                info_str += str(value) + "\n"
+            # information for variables
+            else:
+                # get shape and dimension
+                shape = value.shape
+                dimension = self._dimensions[key]
+
+                # pad shape if required (trailing single dimensions are
+                # discarded following the numpy default)
+                while len(shape) < len(dimension):
+                    shape += (1, )
+
+                # make verbose shape, e.g., '(M=100, R=2, N=128, '
+                shape_verbose = "("
+                for s, d in zip(shape, dimension):
+                    shape_verbose += f"{d}={s}, "
+
+                # add shape information
+                info_str += shape_verbose[:-2] + ")\n"
+                # add value information if not too much
+                if value.size < 7:
+                    info_str += "  " + \
+                        str(np.squeeze(value)).replace("\n", "\n  ") + "\n"
+
+        # write to text file
+        if file is not None:
+            with open(file, 'w') as f_id:
+                f_id.write(info_str + "\n")
+
+        # output to console
+        print(info_str)
+
     def add_variable(self, name, value, dtype, dimensions):
         """
         Add custom variable to the SOFA object, i.e., numeric or string arrays.
@@ -1292,7 +1366,7 @@ def _update_conventions(conventions_path=None):
     if not os.path.isdir(os.path.join(conventions_path, "source")):
         os.mkdir(os.path.join(conventions_path, "source"))
 
-    # Loop conventions
+    # Loop and download conventions if they changed
     updated = False
     for convention in conventions:
 
@@ -1301,7 +1375,6 @@ def _update_conventions(conventions_path=None):
             continue
 
         filename_csv = os.path.join(conventions_path, "source", convention)
-        filename_json = os.path.join(conventions_path, convention[:-3]+"json")
 
         # download SOFA convention definitions to package diretory
         data = requests.get(url_raw + "/" + convention)
@@ -1327,11 +1400,10 @@ def _update_conventions(conventions_path=None):
                 file.write(data)
             print(updated)
 
-        # convert SOFA conventions from csv to json
-        convention_dict = _convention_csv2dict(filename_csv)
-
-        with open(filename_json, 'w') as file:
-            json.dump(convention_dict, file, indent=4)
+    # compile json files from csv file
+    # (this is also done if nothing changed. It won't affect the content of
+    #  the json files but the time-stamp will be updated)
+    _compile_conventions()
 
     if updated:
         print("... done.")
@@ -1339,6 +1411,44 @@ def _update_conventions(conventions_path=None):
         print("... conventions already up to date.")
 
 
+def _compile_conventions(conventions_path=None):
+    """
+    Compile SOFA conventions (json files) from source conventions (csv files
+    from SOFA API_MO), i.e., only do step 2 from `_update_conventions`. This is
+    a helper function for debugging and developing and might break sofar.
+
+    Parameters
+    ----------
+    conventions_path : str
+        Path to the folder containing the conventions as json files (might be
+        empty) and the source convention as csv files in the subfolder `source`
+        (must not be empty). The default is ``None``, which uses the
+        default location inside the sofar package.
+    """
+    # directory handling
+    if conventions_path is None:
+        conventions_path = os.path.join(os.path.dirname(__file__),
+                                        "conventions")
+    if not os.path.isdir(os.path.join(conventions_path, "source")):
+        raise ValueError("conventions_path must contain the folder 'source'")
+
+    # get list of source conventions
+    csv_files = glob.glob(os.path.join(
+        conventions_path, "source", "*.csv"))
+    csv_files = [os.path.split(csv_file)[1] for csv_file in csv_files]
+
+    for csv_file in csv_files:
+
+        # directories for reading and writing
+        json_file = os.path.join(conventions_path, csv_file[:-3] + "json")
+        csv_file = os.path.join(conventions_path, "source", csv_file)
+
+        # convert SOFA conventions from csv to json
+        convention_dict = sf.sofar._convention_csv2dict(csv_file)
+        with open(json_file, 'w') as file:
+            json.dump(convention_dict, file, indent=4)
+
+
 def list_conventions():
     """
     List available SOFA conventions by printing to the console.
@@ -1355,7 +1465,10 @@ def _get_conventions(return_type):
     return_type : string, optional
         ``'path'``
             Return a list with the full paths and filenames of the convention
-            files
+            files (json files)
+        ``'path_source'``
+            Return a list with the full paths and filenames of the source
+            convention files from API_MO (csv files)
         ``'name'``
             Return a list of the convention names without version
         ``'name_version'``
@@ -1369,10 +1482,16 @@ def _get_conventions(return_type):
     See parameter `return_type`.
     """
     # directory containing the SOFA conventions
-    directory = os.path.join(os.path.dirname(__file__), "conventions")
+    if return_type == "path_source":
+        directory = os.path.join(
+            os.path.dirname(__file__), "conventions", "source")
+        reg_str = "*.csv"
+    else:
+        directory = os.path.join(os.path.dirname(__file__), "conventions")
+        reg_str = "*.json"
 
     # SOFA convention files
-    paths = [file for file in glob.glob(os.path.join(directory, "*.json"))]
+    paths = [file for file in glob.glob(os.path.join(directory, reg_str))]
 
     conventions_str = "Available SOFA conventions:\n"
 
@@ -1386,7 +1505,7 @@ def _get_conventions(return_type):
 
     if return_type is None:
         return
-    elif return_type == "path":
+    elif return_type.startswith("path"):
         return paths
     elif return_type == "name":
         return conventions
